========================
``lang.wordnet`` module
========================

.. automodule:: whoosh.lang.wordnet

Thesaurus
=========

.. autoclass:: Thesaurus
	:members:


Low-level functions
===================

.. autofunction:: parse_file
.. autofunction:: synonyms
.. autofunction:: make_index

